package jalview.ws.params;

import jalview.ws.jws2.dm.JabaWsParamSet;

/**
 * Interface implemented by classes for maintaining user's parameters in a Jalview session
 * @author JimP
 *
 */
public interface ParamManager
{
  /**
   * 
   * @param name (may be null) select parameter sets with given name
   * @param serviceUrl (may be null) select parameter sets that are applicable for the given URL
   * @param modifiable - if true, return modifiable parameter sets
   * @param unmodifiable - if true, return server presets
   * @return null if no parameters found, or one or more parameter sets
   */
  public WsParamSetI[] getParameterSet(String name, String serviceUrl, boolean modifiable,boolean unmodifiable);
  /**
   * save the given parameter set in the user's parameter set database.
   * Note: this may result in a modal dialog box being raised.
   * @param parameterSet
   */
  public void storeParameterSet(WsParamSetI parameterSet);
  /**
   * delete the specified parameter set from the database.
   * Note: this may result in a modal dialog box being raised.
   * @param parameterSet
   */
  public void deleteParameterSet(WsParamSetI parameterSet);
  /**
   * register a parser for the given host url
   * @param hosturl
   * @param jabaParamStore
   */
  public void registerParser(String hosturl, ParamDatastoreI paramdataStore);
  

}
